@@ -530,7 +530,7 @@ class DSLibrary(object):
         :param packages:  An iterable of package names, with optional qualifiers like "pandas==1.1.5"
         :param verbose:   By default we inhibit most output.
         """
-        return install_packages(packages, verbose=verbose)
+        raise NotImplementedError()
 
     def _write_content(self, opener, resource_name: str, content, append: bool=False, **kwargs):
         """
@@ -554,10 +554,10 @@ class DSLibrary(object):
             # TODO formulate a bulk INSERT to write to the target table
             # TODO if 'append' is False, we'll have to first drop everything from the table
             # db_conn = self.get_sql_connection(resource_name)
-            raise DSLibraryException("SQL write of columnar data is not yet implemented")
+            raise NotImplementedError("SQL write of columnar data is not yet implemented")
         if format_options.get("nosql_collection"):
             # TODO detect nosql (nosql_collection) and write data there
-            raise DSLibraryException("NoSQL write of columnar data is not yet implemented")
+            raise NotImplementedError("NoSQL write of columnar data is not yet implemented")
         # we detect numpy arrays, series, etc., and save them as a dataframe with one column
         if isinstance(content, (pandas.Series, numpy.ndarray, pandas.Index)):
             series = content
