@@ -167,6 +167,10 @@ class DSLibraryViaMMLibrary(DSLibrary):
             more["_read_only"] = not for_write
         return method(resource_name, **more)
 
+    def set_evaluation_result(self, success: bool, **kwargs) -> None:
+        method = self._find_method("evaluation_result", mandatory=True)
+        method("pass" if success else "fail")
+
     def install_packages(self, packages: list, verbose: bool=False):
         method = self._find_method("install_packages")
         sig = inspect.signature(method)
