@@ -2,7 +2,6 @@
 Implementation of dslibrary that makes REST calls.
 """
 import json
-import urllib.parse
 import re
 import io
 import time
@@ -25,12 +24,12 @@ class DSLibraryViaREST(DSLibrary):
     """
     A model can send all its dslibrary requests over REST and have them handled elsewhere.
     """
-    def __init__(self, url: str, token=None, spec: dict=None):
+    def __init__(self, url: str, token=None, spec: dict=None, auth_header_name: str="X-DSLibrary-Token"):
         super(DSLibraryViaREST, self).__init__(spec=spec)
         if not url.endswith("/"):
             url += "/"
         self._url = url
-        self._headers = {"X-MMLibrary-Token": token} if token else {}
+        self._headers = {auth_header_name: token} if token else {}
         self._session = requests.session() if requests else None
         self._meta = None
         self._context = None
@@ -41,9 +40,9 @@ class DSLibraryViaREST(DSLibrary):
         All HTTP communication goes through here.
         """
         if not self._session:
-            raise DSLibraryException("The 'requests' package is required to use mmlibrary in this mode.")
+            # TODO let's use urllib instead of requests when requests is not available
+            raise DSLibraryException("The 'requests' package is required to use dslibrary in this mode.")
         try:
-            # TODO it would make sense to use urllib instead of requests when requests is not available
             resp = self._session.request(
                 method, self._url + path, params=params, data=data, headers=self._headers, timeout=self._timeouts
             )
@@ -51,8 +50,10 @@ class DSLibraryViaREST(DSLibrary):
         except requests.exceptions.RequestException as err:
             raise DSLibraryCommunicationError(*err.args)
         if as_json:
-            # TODO catch ValueError
-            return resp.json()
+            try:
+                return resp.json()
+            except ValueError as err:
+                raise DSLibraryCommunicationError(f"JSON encoding error: {err}")
         return resp
 
     def _fetch_context(self):
@@ -76,7 +77,7 @@ class DSLibraryViaREST(DSLibrary):
         self._fetch_context()
         return self._context.get("parameters") or {}
 
-    def _open_stream(self, url: str, mode: str, filename: str=None, params: dict=None, chunk_size=5000000):
+    def _open_stream(self, category: str, url: str, mode: str, filename: str=None, params: dict=None, chunk_size=5000000):
         """
         General purpose read/write file streams over HTTP.
         """
@@ -84,25 +85,25 @@ class DSLibraryViaREST(DSLibrary):
             raise ValueError("invalid mode: %s" % mode)
         if "r" in mode:
             def read_chunk(start, end):
-                resp = self._do_comm("get", url, params={"byte_range": json.dumps([start, end]), **(params or {})}, as_json=False)
+                resp = self._do_comm("get", category, params={"resource_name": url, "byte_range": json.dumps([start, end]), **(params or {})}, as_json=False)
                 return resp.content if "b" in mode else resp.text
             return filechunker.ChunkedFileReader(filename, reader=read_chunk, mode=mode, chunk_size=chunk_size)
         else:
             def write_chunk(content, append, hint=None):
                 if ("b" in mode) == isinstance(content, str):
                     raise TypeError("incorrect data type for mode=%s" % mode)
-                resp = self._do_comm("put", url, params={"append": append, "hint": hint}, data=content)
+                resp = self._do_comm("put", category, params={"resource_name": url, "append": append, "hint": hint}, data=content)
                 return resp.get("upload_id")
             return filechunker.ChunkedFileWriter(filename, writer=write_chunk, mode=mode)
 
     def _opener(self, path: str, mode: str, **kwargs) -> io.IOBase:
-        return self._open_stream("resources/%s" % urllib.parse.quote(path), mode, filename=path)
+        return self._open_stream("resources", path, mode, filename=path)
 
     def open_run_data(self, filename: str, mode: str='rb') -> io.RawIOBase:
         """
         Shared pipeline data has a different endpoint.
         """
-        return self._open_stream("run_data/%s" % urllib.parse.quote(filename), mode, filename=filename)
+        return self._open_stream("run_data", filename, mode, filename=filename)
 
     def next_scoring_request(self, timeout: float=None) -> (dict, None):
         """
